@@ -1,7 +1,7 @@
 package Perinci::Examples::FileStream;
 
-our $DATE = '2015-01-04'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2015-01-11'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010;
 use strict;
@@ -16,7 +16,7 @@ $SPEC{':package'} = {
     summary => 'Examples for reading/writing files (using streaming result)',
     description => <<'_',
 
-The functions in this package demos streaming input and output.
+The functions in this package demonstrate byte streaming of input and output.
 
 The functions are separated into this module because these functions read/write
 files on the filesystem and might potentially be dangerous if
@@ -34,6 +34,22 @@ $SPEC{read_file} = {
         path => {schema=>'str*', req=>1, pos=>0},
     },
     result => {schema=>'buf*', stream=>1},
+    description => <<'_',
+
+This function demonstrate output streaming of bytes.
+
+To do output streaming, on the function side, you just return an opened
+filehandle glob which can be read from, or an `IO::Handle` object (anything that
+supports `getline()` or `getitem()` method) or an array (usually a tied array).
+
+`Perinci::CmdLine` supports this and will read items/lines from the
+handle/object/tied array until exhausted, and then output them.
+
+This works over remote (HTTP) too, because output streaming is supported by
+`Riap::HTTP` (version 1.2) and `Perinci::Access::HTTP::Client`. Streams are
+translated into HTTP chunks.
+
+_
 };
 sub read_file {
     my %args = @_; my $_sahv_dpath = []; my $arg_err; if (exists($args{'path'})) { ((defined($args{'path'})) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Required but not specified"),0)) && ((!ref($args{'path'})) ? 1 : (($arg_err //= (@$_sahv_dpath ? '@'.join("/",@$_sahv_dpath).": " : "") . "Not of type text"),0)); if ($arg_err) { return [400, "Invalid argument value for path: $arg_err"] } }if (!exists($args{'path'})) { return [400, "Missing argument: path"] } # VALIDATE_ARGS
@@ -50,7 +66,23 @@ $SPEC{write_file} = {
     v => 1.1,
     description => <<'_',
 
-Overwrites existing file.
+This function demonstrates input streaming of bytes.
+
+To do input streaming, on the function side, you just specify one your args with
+the `stream` property set to true (`stream => 1`). In this example, the
+`content` argument is set to streaming.
+
+If you run the function through `Perinci::CmdLine`, you'll get a filehandle
+instead of the actual value. You can then iterate the content from this
+filehandle. This currently works for local functions only. As of this writing,
+`Riap::HTTP` protocol does not support input streaming. It supports partial
+input though (see the documentation on how this works) and theoretically
+streaming can be emulated by client library using partial input. However, client
+like `Perinci::Access::HTTP::Client` does not yet support this.
+
+Note that the argument's schema is still `buf*`, not `obj*`.
+
+Note: This function overwrites existing file.
 
 _
     args => {
@@ -84,6 +116,9 @@ $SPEC{append_file} = {
     v => 1.1,
     description => <<'_',
 
+This is like `write_file()` except that it appends instead of overwrites
+existing file.
+
 _
     args => {
         path => {schema=>'str*', req=>1, pos=>0},
@@ -127,12 +162,12 @@ Perinci::Examples::FileStream - Examples for reading/writing files (using stream
 
 =head1 VERSION
 
-This document describes version 0.45 of Perinci::Examples::FileStream (from Perl distribution Perinci-Examples), released on 2015-01-04.
+This document describes version 0.46 of Perinci::Examples::FileStream (from Perl distribution Perinci-Examples), released on 2015-01-11.
 
 =head1 DESCRIPTION
 
 
-The functions in this package demos streaming input and output.
+The functions in this package demonstrate byte streaming of input and output.
 
 The functions are separated into this module because these functions read/write
 files on the filesystem and might potentially be dangerous if
@@ -146,6 +181,9 @@ of streaming.
 
 =head2 append_file(%args) -> [status, msg, result, meta]
 
+This is like C<write_file()> except that it appends instead of overwrites
+existing file.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -167,8 +205,22 @@ that contains extra information.
 
 Return value:  (any)
 
+
 =head2 read_file(%args) -> [status, msg, result, meta]
 
+This function demonstrate output streaming of bytes.
+
+To do output streaming, on the function side, you just return an opened
+filehandle glob which can be read from, or an C<IO::Handle> object (anything that
+supports C<getline()> or C<getitem()> method) or an array (usually a tied array).
+
+C<Perinci::CmdLine> supports this and will read items/lines from the
+handle/object/tied array until exhausted, and then output them.
+
+This works over remote (HTTP) too, because output streaming is supported by
+C<Riap::HTTP> (version 1.2) and C<Perinci::Access::HTTP::Client>. Streams are
+translated into HTTP chunks.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -188,9 +240,26 @@ that contains extra information.
 
 Return value:  (buf)
 
+
 =head2 write_file(%args) -> [status, msg, result, meta]
 
-Overwrites existing file.
+This function demonstrates input streaming of bytes.
+
+To do input streaming, on the function side, you just specify one your args with
+the C<stream> property set to true (C<< stream =E<gt> 1 >>). In this example, the
+C<content> argument is set to streaming.
+
+If you run the function through C<Perinci::CmdLine>, you'll get a filehandle
+instead of the actual value. You can then iterate the content from this
+filehandle. This currently works for local functions only. As of this writing,
+C<Riap::HTTP> protocol does not support input streaming. It supports partial
+input though (see the documentation on how this works) and theoretically
+streaming can be emulated by client library using partial input. However, client
+like C<Perinci::Access::HTTP::Client> does not yet support this.
+
+Note that the argument's schema is still C<buf*>, not C<obj*>.
+
+Note: This function overwrites existing file.
 
 Arguments ('*' denotes required arguments):
 
@@ -212,6 +281,7 @@ element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
